==> haskell-serialise-0.2.3.0-129-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-serialise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 serialise
version:              0.2.3.0
visibility:           public
id:                   serialise-0.2.3.0-1F7FuS6pz2O3oYEAlMDuiJ
key:                  serialise-0.2.3.0-1F7FuS6pz2O3oYEAlMDuiJ
license:              BSD-3-Clause
copyright:
    2015-2017 Duncan Coutts,
    2015-2017 Well-Typed LLP,
    2015 IRIS Connect Ltd

maintainer:           duncan@community.haskell.org, ben@smart-cactus.org
author:               Duncan Coutts
homepage:             https://github.com/well-typed/cborg
synopsis:             A binary serialisation library for Haskell values.
description:
    This package (formerly @binary-serialise-cbor@) provides pure, efficient
    serialization of Haskell values directly into @ByteString@s for storage or
    transmission purposes. By providing a set of type class instances, you can
    also serialise any custom data type you have as well.

    The underlying binary format used is the '\''Concise Binary Object
    Representation'\'', or CBOR, specified in RFC 7049. As a result,
    serialised Haskell values have implicit structure outside of the
    Haskell program itself, meaning they can be inspected or analyzed
    without custom tools.

    An implementation of the standard bijection between CBOR and JSON is provided
    by the [cborg-json](/package/cborg-json) package. Also see
    [cbor-tool](/package/cbor-tool) for a convenient command-line utility for
    working with CBOR data.

category:             Codec
abi:                  7ec904ceafad99c0d0562a2cdeb38c78
exposed:              True
exposed-modules:
    Codec.Serialise Codec.Serialise.Class Codec.Serialise.Decoding
    Codec.Serialise.Encoding Codec.Serialise.IO
    Codec.Serialise.Internal.GeneralisedUTF8 Codec.Serialise.Properties
    Codec.Serialise.Tutorial

import-dirs:          /usr/lib/ghc-8.10.4/site-local/serialise-0.2.3.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/serialise-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/serialise-0.2.3.0
hs-libraries:         HSserialise-0.2.3.0-1F7FuS6pz2O3oYEAlMDuiJ
depends:
    array-0.5.4.0 base-4.14.1.0 bytestring-0.10.12.0
    cborg-0.2.5.0-CDoHoNyJywBKewOyVVwo2h containers-0.6.2.1
    ghc-prim-0.6.1 half-0.3.1-EYqTLuHAof4DRJxRflEEaf
    hashable-1.3.1.0-4EsGp1K7uOu2cACWuCidz3
    primitive-0.7.1.0-8SQOE2avl1z6s0yo5beOHC text-1.2.4.1 time-1.9.3
    unordered-containers-0.2.13.0-4AoMTstniRpGNa4LW5BINH
    vector-0.12.3.0-H4rWOat9KWYJKIFglDYjhy

haddock-interfaces:   /usr/share/doc/haskell-serialise/html/serialise.haddock
haddock-html:         /usr/share/doc/haskell-serialise/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-serialise-0.2.3.0-130-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-serialise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 serialise
version:              0.2.3.0
visibility:           public
id:                   serialise-0.2.3.0-AE7WeYfaUkqAHNG83JH4FV
key:                  serialise-0.2.3.0-AE7WeYfaUkqAHNG83JH4FV
license:              BSD-3-Clause
copyright:
    2015-2017 Duncan Coutts,
    2015-2017 Well-Typed LLP,
    2015 IRIS Connect Ltd

maintainer:           duncan@community.haskell.org, ben@smart-cactus.org
author:               Duncan Coutts
homepage:             https://github.com/well-typed/cborg
synopsis:             A binary serialisation library for Haskell values.
description:
    This package (formerly @binary-serialise-cbor@) provides pure, efficient
    serialization of Haskell values directly into @ByteString@s for storage or
    transmission purposes. By providing a set of type class instances, you can
    also serialise any custom data type you have as well.

    The underlying binary format used is the '\''Concise Binary Object
    Representation'\'', or CBOR, specified in RFC 7049. As a result,
    serialised Haskell values have implicit structure outside of the
    Haskell program itself, meaning they can be inspected or analyzed
    without custom tools.

    An implementation of the standard bijection between CBOR and JSON is provided
    by the [cborg-json](/package/cborg-json) package. Also see
    [cbor-tool](/package/cbor-tool) for a convenient command-line utility for
    working with CBOR data.

category:             Codec
abi:                  f115cdc884216c4f62015ffff908d1c5
exposed:              True
exposed-modules:
    Codec.Serialise Codec.Serialise.Class Codec.Serialise.Decoding
    Codec.Serialise.Encoding Codec.Serialise.IO
    Codec.Serialise.Internal.GeneralisedUTF8 Codec.Serialise.Properties
    Codec.Serialise.Tutorial

import-dirs:          /usr/lib/ghc-8.10.4/site-local/serialise-0.2.3.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/serialise-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/serialise-0.2.3.0
hs-libraries:         HSserialise-0.2.3.0-AE7WeYfaUkqAHNG83JH4FV
depends:
    array-0.5.4.0 base-4.14.1.0 bytestring-0.10.12.0
    cborg-0.2.5.0-8eV5aFN0SH9EPTuJ9FF5iH containers-0.6.2.1
    ghc-prim-0.6.1 half-0.3.1-8zhdpLnkj7YDr3Alw1zqIr
    hashable-1.3.1.0-1TzQw0rlraYH9EvMt0jxBh
    primitive-0.7.1.0-HszRJTbIytQDXhFpW7xbnI text-1.2.4.1 time-1.9.3
    unordered-containers-0.2.13.0-6CorcJuUNAZJ43lHhm1xtn
    vector-0.12.3.0-IwaLbQErzPq95Qm3ml0M2u

haddock-interfaces:   /usr/share/doc/haskell-serialise/html/serialise.haddock
haddock-html:         /usr/share/doc/haskell-serialise/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
